@@ -15,18 +15,19 @@ from threading import Thread
 STRICT = "UPGRADE_ADVISORY" not in os.environ
 
 BUNDLED = ["pip", "setuptools", "wheel"]
-SUPPORT = [(3, i) for i in range(7, 14)]
+SUPPORT = [(3, i) for i in range(8, 15)]
 DEST = Path(__file__).resolve().parents[1] / "src" / "virtualenv" / "seed" / "wheels" / "embed"
 
 
 def download(ver, dest, package):
     subprocess.call(
-        [  # noqa: S603
+        [
             sys.executable,
             "-m",
             "pip",
             "--disable-pip-version-check",
             "download",
+            "--no-cache-dir",
             "--only-binary=:all:",
             "--python-version",
             ver,
@@ -66,8 +67,8 @@ def run():  # noqa: C901
 
         added = collect_package_versions(new_packages)
         removed = collect_package_versions(remove_packages)
-
         outcome = (1 if STRICT else 0) if (added or removed) else 0
+        print(f"Outcome {outcome} added {added} removed {removed}")  # noqa: T201
         lines = ["Upgrade embedded wheels:", ""]
         for key, versions in added.items():
             text = f"* {key} to {fmt_version(versions)}"
@@ -119,8 +120,8 @@ def run():  # noqa: C901
         )
         dest_target = DEST / "__init__.py"
         dest_target.write_text(msg, encoding="utf-8")
-
-        subprocess.run([sys.executable, "-m", "ruff", str(dest_target), "--fix", "--unsafe-fixes"], check=False)  # noqa: S603
+        subprocess.run([sys.executable, "-m", "ruff", "check", str(dest_target), "--fix", "--unsafe-fixes"])
+        subprocess.run([sys.executable, "-m", "ruff", "format", str(dest_target), "--preview"])
 
         raise SystemExit(outcome)
 
