@@ -58,7 +58,7 @@ def link_folder(has_symlink_support):
         return os.symlink
     if sys.platform == "win32":
         # on Windows junctions may be used instead
-        import _winapi
+        import _winapi  # noqa: PLC0415
 
         return getattr(_winapi, "CreateJunction", None)
     return None
@@ -126,7 +126,7 @@ def _ensure_py_info_cache_empty(session_app_data):
 @contextmanager
 def change_os_environ(key, value):
     env_var = key
-    previous = os.environ[env_var] if env_var in os.environ else None
+    previous = os.environ.get(env_var, None)
     os.environ[env_var] = value
     try:
         yield
@@ -197,7 +197,7 @@ def coverage_env(monkeypatch, link, request):
     """
     if COVERAGE_RUN and "_no_coverage" not in request.fixturenames:
         # we inject right after creation, we cannot collect coverage on site.py - used for helper scripts, such as debug
-        from virtualenv import run
+        from virtualenv import run  # noqa: PLC0415
 
         def _session_via_cli(args, options, setup_logging, env=None):
             session = prev_run(args, options, setup_logging, env)
@@ -206,7 +206,7 @@ def coverage_env(monkeypatch, link, request):
             def create_run():
                 result = old_run()
                 obj["cov"] = EnableCoverage(link)
-                obj["cov"].__enter__(session.creator)
+                obj["cov"].__enter__(session.creator)  # noqa: PLC2801
                 return result
 
             monkeypatch.setattr(session.creator, "run", create_run)
@@ -234,7 +234,7 @@ def coverage_env(monkeypatch, link, request):
 
 
 # _no_coverage tells coverage_env to disable coverage injection for _no_coverage user.
-@pytest.fixture()
+@pytest.fixture
 def _no_coverage():
     pass
 
@@ -275,7 +275,11 @@ def is_inside_ci():
 
 @pytest.fixture(scope="session")
 def special_char_name():
-    base = "e-$ èрт🚒♞中片-j"
+    base = "'\";&&e-$ èрт🚒♞中片-j"
+    if IS_WIN:
+        # get rid of invalid characters on Windows
+        base = base.replace('"', "")
+        base = base.replace(";", "")
     # workaround for pypy3 https://bitbucket.org/pypy/pypy/issues/3147/venv-non-ascii-support-windows
     encoding = "ascii" if IS_WIN else sys.getfilesystemencoding()
     # let's not include characters that the file system cannot encode)
@@ -291,7 +295,7 @@ def special_char_name():
     return result
 
 
-@pytest.fixture()
+@pytest.fixture
 def special_name_dir(tmp_path, special_char_name):
     return Path(str(tmp_path)) / special_char_name
 
@@ -332,7 +336,7 @@ def change_env_var(key, value):
             del os.environ[key]  # pragma: no cover
 
 
-@pytest.fixture()
+@pytest.fixture
 def temp_app_data(monkeypatch, tmp_path):
     app_data = tmp_path / "app-data"
     monkeypatch.setenv("VIRTUALENV_OVERRIDE_APP_DATA", str(app_data))
@@ -344,21 +348,21 @@ def for_py_version():
     return f"{sys.version_info.major}.{sys.version_info.minor}"
 
 
-@pytest.fixture()
+@pytest.fixture
 def _skip_if_test_in_system(session_app_data):
     current = PythonInfo.current(session_app_data)
     if current.system_executable is not None:
         pytest.skip("test not valid if run under system")
 
 
-if IS_PYPY:
+if IS_PYPY or (IS_WIN and sys.version_info[0:2] >= (3, 13)):  # https://github.com/adamchainz/time-machine/issues/456
 
-    @pytest.fixture()
+    @pytest.fixture
     def time_freeze(freezer):
         return freezer.move_to
 
 else:
 
-    @pytest.fixture()
+    @pytest.fixture
     def time_freeze(time_machine):
         return lambda s: time_machine.move_to(s, tick=False)
