@@ -11,6 +11,7 @@ import site
 import stat
 import subprocess
 import sys
+import textwrap
 import zipfile
 from collections import OrderedDict
 from itertools import product
@@ -77,13 +78,12 @@ def test_destination_not_write_able(tmp_path, capsys):
 
 
 def cleanup_sys_path(paths):
-    from virtualenv.create.creator import HERE
+    from virtualenv.create.creator import HERE  # noqa: PLC0415
 
     paths = [p.resolve() for p in (Path(os.path.abspath(i)) for i in paths) if p.exists()]
     to_remove = [Path(HERE)]
     if os.environ.get("PYCHARM_HELPERS_DIR"):
-        to_remove.append(Path(os.environ["PYCHARM_HELPERS_DIR"]).parent)
-        to_remove.append(Path(os.path.expanduser("~")) / ".PyCharm")
+        to_remove.extend((Path(os.environ["PYCHARM_HELPERS_DIR"]).parent, Path(os.path.expanduser("~")) / ".PyCharm"))
     return [i for i in paths if not any(str(i).startswith(str(t)) for t in to_remove)]
 
 
@@ -224,6 +224,33 @@ def test_create_no_seed(  # noqa: C901, PLR0912, PLR0913, PLR0915
     assert git_ignore.splitlines() == [comment, "*"]
 
 
+def test_create_cachedir_tag(tmp_path):
+    cachedir_tag_file = tmp_path / "CACHEDIR.TAG"
+    cli_run([str(tmp_path), "--without-pip", "--activators", ""])
+
+    expected = """
+    Signature: 8a477f597d28d172789f06886806bc55
+    # This file is a cache directory tag created by Python virtualenv.
+    # For information about cache directory tags, see:
+    #   https://bford.info/cachedir/
+    """
+    assert cachedir_tag_file.read_text(encoding="utf-8") == textwrap.dedent(expected).strip()
+
+
+def test_create_cachedir_tag_exists(tmp_path: Path) -> None:
+    cachedir_tag_file = tmp_path / "CACHEDIR.TAG"
+    cachedir_tag_file.write_text("magic", encoding="utf-8")
+    cli_run([str(tmp_path), "--without-pip", "--activators", ""])
+    assert cachedir_tag_file.read_text(encoding="utf-8") == "magic"
+
+
+def test_create_cachedir_tag_exists_override(tmp_path: Path) -> None:
+    cachedir_tag_file = tmp_path / "CACHEDIR.TAG"
+    cachedir_tag_file.write_text("magic", encoding="utf-8")
+    cli_run([str(tmp_path), "--without-pip", "--activators", ""])
+    assert cachedir_tag_file.read_text(encoding="utf-8") == "magic"
+
+
 def test_create_vcs_ignore_exists(tmp_path):
     git_ignore = tmp_path / ".gitignore"
     git_ignore.write_text("magic", encoding="utf-8")
@@ -438,6 +465,7 @@ def list_files(path):
 
 
 @pytest.mark.skipif(is_macos_brew(CURRENT), reason="no copy on brew")
+@pytest.mark.skip(reason="https://github.com/pypa/setuptools/issues/4640")
 def test_zip_importer_can_import_setuptools(tmp_path):
     """We're patching the loaders so might fail on r/o loaders, such as zipimporter on CPython<3.8"""
     result = cli_run(
@@ -485,10 +513,9 @@ def test_no_preimport_threading(tmp_path):
 # verify that .pth files in site-packages/ are always processed even if $PYTHONPATH points to it.
 def test_pth_in_site_vs_python_path(tmp_path):
     session = cli_run([str(tmp_path)])
-    site_packages = str(session.creator.purelib)
+    site_packages = session.creator.purelib
     # install test.pth that sets sys.testpth='ok'
-    with open(os.path.join(site_packages, "test.pth"), "w", encoding="utf-8") as f:
-        f.write('import sys; sys.testpth="ok"\n')
+    (session.creator.purelib / "test.pth").write_text('import sys; sys.testpth="ok"\n', encoding="utf-8")
     # verify that test.pth is activated when interpreter is run
     out = subprocess.check_output(
         [str(session.creator.exe), "-c", r"import sys; print(sys.testpth)"],
@@ -498,7 +525,7 @@ def test_pth_in_site_vs_python_path(tmp_path):
     assert out == "ok\n"
     # same with $PYTHONPATH pointing to site_packages
     env = os.environ.copy()
-    path = [site_packages]
+    path = [str(site_packages)]
     if "PYTHONPATH" in env:
         path.append(env["PYTHONPATH"])
     env["PYTHONPATH"] = os.pathsep.join(path)
@@ -650,7 +677,7 @@ def test_python_path(monkeypatch, tmp_path, python_path_on):
 # https://github.com/pypa/virtualenv/issues/2419
 @pytest.mark.skipif("venv" not in CURRENT_CREATORS, reason="test needs venv creator")
 def test_venv_creator_without_write_perms(tmp_path, mocker):
-    from virtualenv.run.session import Session
+    from virtualenv.run.session import Session  # noqa: PLC0415
 
     prev = Session._create  # noqa: SLF001
 
