@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import os
 import shutil
 import subprocess
@@ -33,16 +35,25 @@ def builtin_shows_marker_missing():
     not Path(CURRENT.system_include).exists() and not builtin_shows_marker_missing(),
     reason="Building C-Extensions requires header files with host python",
 )
-@pytest.mark.parametrize("creator", [i for i in CREATOR_CLASSES.keys() if i != "builtin"])
+@pytest.mark.parametrize("creator", [i for i in CREATOR_CLASSES if i != "builtin"])
 def test_can_build_c_extensions(creator, tmp_path, coverage_env):
     env, greet = tmp_path / "env", str(tmp_path / "greet")
     shutil.copytree(str(Path(__file__).parent.resolve() / "greet"), greet)
     session = cli_run(["--creator", creator, "--seeder", "app-data", str(env), "-vvv"])
     coverage_env()
+    setuptools_index_args = ()
+    if CURRENT.version_info >= (3, 12):
+        # requires to be able to install setuptools as build dependency
+        setuptools_index_args = (
+            "--find-links",
+            "https://pypi.org/simple/setuptools/",
+        )
+
     cmd = [
         str(session.creator.script("pip")),
         "install",
         "--no-index",
+        *setuptools_index_args,
         "--no-deps",
         "--disable-pip-version-check",
         "-vvv",
@@ -56,6 +67,7 @@ def test_can_build_c_extensions(creator, tmp_path, coverage_env):
         [str(session.creator.exe), "-c", "import greet; greet.greet('World')"],
         universal_newlines=True,
         stdout=subprocess.PIPE,
+        encoding="utf-8",
     )
     out, _ = process.communicate()
     assert process.returncode == 0
